xlwt HISTORY

Version 0.7.2, released to the general public via PyPI -- 2009-06-01

`
Revision: 3844
Author: sjmachin
Date: 11:02:54 AM, Wednesday, 20 May 2009
Message:
Added function Utils.rowcol_pair_to_cellrange. (0, 0, 65535, 255) -> "A1:IV65536"
----
Modified : /xlwt/trunk/xlwt/Utils.py
Revision: 3843
Author: sjmachin
Date: 1:46:05 AM, Tuesday, 19 May 2009
Message:
Removed Worksheet property show_empty_as_zero,
and added attribute show_zero_values (default: 1 == True).
----
Modified : /xlwt/trunk/xlwt/Worksheet.py
Revision: 3841
Author: sjmachin
Date: 11:58:51 AM, Wednesday, 13 May 2009
Message:
Fixed formula code generation problem with formulas
including MAX/SUM/etc functions with arguments like A1+123.
Updated version to 0.7.2alpha.
----
Modified : /xlwt/trunk/README.html
Modified : /xlwt/trunk/setup.py
Modified : /xlwt/trunk/xlwt/ExcelFormulaParser.py
Modified : /xlwt/trunk/xlwt/ExcelMagic.py
Modified : /xlwt/trunk/xlwt/__init__.py
Modified : /xlwt/trunk/xlwt/excel-formula.g
Revision: 3816
Author: sjmachin
Date: 8:31:39 PM, Tuesday, 24 March 2009
Message:
Added .../doc/pattern_examples.xls and put a pointer to it
in the easyxf part of Style.py.
----
Modified : /xlwt/trunk/xlwt/Style.py
Added : /xlwt/trunk/xlwt/doc/pattern_examples.xls
Revision: 3815
Author: sjmachin
Date: 7:54:52 PM, Tuesday, 24 March 2009
Message:
Fixed Row.set_cell_formula() bug introduced in 0.7.1.
Fixed bug(?) with SCL/magnification handling causing(?) Excel
to raise a dialogue box if sheet is set to open in page preview mode
and user then switches to normal view.
Added color and colour as synonyms for font.colour_index in easyxf.
Removed unused attribute Row.__has_default_format.
----
Modified : /xlwt/trunk/xlwt/Row.py
Modified : /xlwt/trunk/xlwt/Style.py
Modified : /xlwt/trunk/xlwt/Worksheet.py`

Version 0.7.1, released to the general public via PyPI -- 2009-03-04

Version 0.7.0, released to the general public via PyPI

- Fixed more bugs and added more various new bits of functionality

Version 0.7.0a4, fork of pyExcelerator, released to python-excel.

- Fixed various bugs in pyExcelerator and added various new bits of functionality